@@ -13,7 +13,6 @@ from flvlib.constants import H264_PACKET_TYPE_SEQUENCE_HEADER
 from flvlib.primitives import make_ui8, make_ui24, make_si32_extended
 from flvlib.astypes import MalformedFLV
 from flvlib.tags import FLV, EndOfFile, AudioTag, VideoTag, ScriptTag
-from flvlib.tags import create_script_tag, create_flv_header
 from flvlib.helpers import force_remove
 
 log = logging.getLogger('flvlib.retimestamp-flv')
@@ -70,7 +69,7 @@ def retimestamp_tags_inplace(f, fu):
             fu.write(make_si32_extended(tag.timestamp - offset))
 
 
-def retimestamp_file_inplace(inpath):
+def retimestamp_file_inplace(inpath, strict):
     try:
         f = open(inpath, 'rb')
         fu = open(inpath, 'rb+')
@@ -88,8 +87,10 @@ def retimestamp_file_inplace(inpath):
         log.error("The file `%s' is not a valid FLV file: %s", inpath, message)
         return False
     except EndOfFile:
-        log.error("Unexpected end of file on file `%s'", inpath)
-        return False
+        if strict:
+            log.error("Unexpected end of file on file `%s'", inpath)
+            return False
+        log.warning("Unexpected end of file on file `%s'", inpath)
 
     f.close()
     fu.close()
@@ -97,7 +98,7 @@ def retimestamp_file_inplace(inpath):
     return True
 
 
-def retimestamp_file_atomically(inpath, outpath):
+def retimestamp_file_atomically(inpath, outpath, strict):
     try:
         f = open(inpath, 'rb')
     except IOError, (errno, strerror):
@@ -144,10 +145,12 @@ def retimestamp_file_atomically(inpath, outpath):
             force_remove(temppath)
         return False
     except EndOfFile:
-        log.error("Unexpected end of file on file `%s'", inpath)
-        if not outpath:
-            force_remove(temppath)
-        return False
+        if strict:
+            log.error("Unexpected end of file on file `%s'", inpath)
+            if not outpath:
+                force_remove(temppath)
+            return False
+        log.warning("Unexpected end of file on file `%s'", inpath)
 
     f.close()
     fo.close()
@@ -165,16 +168,16 @@ def retimestamp_file_atomically(inpath, outpath):
     return True
 
 
-def retimestamp_file(inpath, outpath=None, inplace=False):
+def retimestamp_file(inpath, outpath=None, inplace=False, strict=False):
     out_text = (outpath and ("into file `%s'" % outpath)) or "and overwriting"
     log.debug("Retimestamping file `%s' %s", inpath, out_text)
 
     if inplace:
         log.debug("Operating in inplace mode")
-        return retimestamp_file_inplace(inpath)
+        return retimestamp_file_inplace(inpath, strict)
     else:
         log.debug("Not operating in inplace mode, using temporary files")
-        return retimestamp_file_atomically(inpath, outpath)
+        return retimestamp_file_atomically(inpath, outpath, strict)
 
 
 def process_options():
@@ -195,6 +198,8 @@ def process_options():
     parser.add_option("-U", "--update", action="store_true",
                       help=("update mode, overwrites the given files "
                             "instead of writing to outfile"))
+    parser.add_option("-s", "--strict", action="store_true",
+                      help="be strict while parsing the FLV file")
     parser.add_option("-v", "--verbose", action="count",
                       default=0, dest="verbosity",
                       help="be more verbose, each -v increases verbosity")
@@ -225,11 +230,15 @@ def retimestamp_files():
 
     clean_run = True
 
+    if options.strict:
+        tags.STRICT_PARSING = True
+
     if not options.update:
-        clean_run = retimestamp_file(args[1], args[2])
+        clean_run = retimestamp_file(args[1], args[2], strict=options.strict)
     else:
         for filename in args[1:]:
-            if not retimestamp_file(filename, inplace=options.inplace):
+            if not retimestamp_file(filename, inplace=options.inplace,
+                                    strict=options.strict):
                 clean_run = False
 
     return clean_run
